MCD weak
Exemplaire ( #œuvre, exemplaire, nb pages, date achat, foobar )

- Le champ œuvre fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité Œuvre pour renforcer l'identifiant.
- Le champ exemplaire fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité Exemplaire.
- Les champs nb pages et date achat étaient déjà de simples attributs de l'entité Exemplaire.
- Le champ foobar a migré à partir de l'association de dépendance fonctionnelle DF.

Œuvre ( œuvre, auteur )

- Le champ œuvre constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Œuvre.
- Le champ auteur était déjà un simple attribut de l'entité Œuvre.